function pix = findSeam_Dyn(energy)
%FINDSEAM_DYN: Part B(ii)
%INPUT:
%   energy: the 2D matrix of image energy that you calculated in part (a)
%OUTPUT: 
%   pix is a 1-D array of the column indices in the seam to be removed
